@@ -86,7 +86,7 @@ class KToolBar;
  * readProperties(). To save special data about your data, reimplement
  * saveGlobalProperties(). To warn user that application or
  * windows have unsaved data on close or logout, reimplement
- * queryClose() and/or queryExit().
+ * queryClose().
  *
  * You have to implement session restoring also in your main() function.
  * There are also kRestoreMainWindows convenience functions which
@@ -260,7 +260,6 @@ public:
      * <i>Note that you don't need to deal with this function. Use the
      * kRestoreMainWindows() convenience template function instead!</i>
      * @see kRestoreMainWindows()
-     * @see #RESTORE
      * @see readProperties()
      * @see canBeRestored()
      */
@@ -324,7 +323,7 @@ public:
      *   "virtual QSize sizeHint() const;" to specify a default size rather
      *   than letting QWidget::adjust use the default size of 0x0.
      */
-    void setAutoSaveSettings(const QString &groupName = QStringLiteral("MainWindow"),
+    void setAutoSaveSettings(const QString &groupName = QLatin1String("MainWindow"),
                              bool saveWindowSize = true);
 
     /**
@@ -465,54 +464,14 @@ protected:
     virtual bool event(QEvent *event);
 
     /**
-     * Reimplemented to call the queryClose() and queryExit() handlers.
+     * Reimplemented to autosave settings and call queryClose().
      *
-     * We recommend that you reimplement the handlers rather than closeEvent().
+     * We recommend that you reimplement queryClose() rather than closeEvent().
      * If you do it anyway, ensure to call the base implementation to keep
-     * queryExit() running.
+     * the feature of auto-saving window settings working.
      */
     virtual void closeEvent(QCloseEvent *);
 
-    // KDE4 This seems to be flawed to me. Either the app has only one
-    // mainwindow, so queryClose() is enough, or if it can have more of them,
-    // then the windows should take care of themselves, and queryExit()
-    // would be useful only for the annoying 'really quit' dialog, which
-    // also doesn't make sense in apps with multiple mainwindows.
-    // And saving configuration in something called queryExit()? IMHO
-    // one can e.g. use QCoreApplication::aboutToQuit(), which if nothing else
-    // has at least better fitting name.
-    // See also KApplication::sessionSaving().
-    // This stuff should get changed somehow, so that it at least doesn't
-    // mess with session management.
-    /**
-       Called before the very last window is closed, either by the
-       user or indirectly by the session manager.
-
-       It is not recommended to do any user interaction in this
-       function other than indicating severe errors. Better ask the
-       user on queryClose() (see below).
-
-       A typical usage of queryExit() is to write configuration data back.
-       Note that the application may continue to run after queryExit()
-       (the user may have canceled a shutdown), so you should not do any cleanups
-       here. The purpose of queryExit() is purely to prepare the application
-       (with possible user interaction) so it can safely be closed later (without
-       user interaction).
-
-       If you need to do serious things on exit (like shutting a
-       dial-up connection down), connect to the signal
-    QCoreApplication::aboutToQuit().
-
-       Default implementation returns @p true. Returning @p false will
-       cancel the exiting. In the latter case, the last window will
-       remain visible. If KApplication::sessionSaving() is true, refusing
-       the exit will also cancel KDE logout.
-
-       @see queryClose()
-       @see KApplication::sessionSaving()
-     */
-    virtual bool queryExit();
-
     /**
        Called before the window is closed, either by the user or indirectly by
        the session manager.
@@ -544,7 +503,6 @@ protected:
        its location might not be properly saved. In addition, the session shutdown
        may be canceled, in which case the document should remain open.
 
-       @see queryExit()
        @see KApplication::sessionSaving()
     */
     virtual bool queryClose();
@@ -674,7 +632,6 @@ protected:
 
     KMainWindowPrivate *const k_ptr;
 private:
-    Q_PRIVATE_SLOT(k_func(), void _k_shuttingDown())
     Q_PRIVATE_SLOT(k_func(), void _k_slotSettingsChanged(int))
     Q_PRIVATE_SLOT(k_func(), void _k_slotSaveAutoSaveSize())
 };
@@ -682,34 +639,16 @@ private:
 /**
  * @def RESTORE
  * @ingroup XMLGUIMacros
- * Restores the last session. (To be used in your main function).
+ * Restores the last session.
  *
- * If your client has only one kind of toplevel widgets (which
- * should be pretty usual) then you can use this macro,
- * which is provided for backwards compatibility with 3.1 and 3.0
- * branches:
- *
- * \code
- * if (qApp->isSessionRestored())
- *   RESTORE(childMW)
- * else {
- *   // create default application as usual
- * }
- * \endcode
- *
- * The macro expects the type of your toplevel widget as argument.
- *
- * Since KDE4, you can also use kRestoreMainWindows(), which
- * supports also clients with more than one kind of toplevel
- * widgets.
- *
- * @see KMainWindow::restore()
- * @see kRestoreMainWindows()
+ * @deprecated since 5.0, use kRestoreMainWindows() instead
  **/
+#ifndef KXMLGUI_NO_DEPRECATED
 #define RESTORE(type) { int n = 1;\
         while (KMainWindow::canBeRestored(n)){\
             (new type)->restore(n);\
             n++;}}
+#endif
 
 /**
  * @def KDE_RESTORE_MAIN_WINDOWS_NUM_TEMPLATE_ARGS
@@ -746,13 +685,7 @@ private:
  * deciding whether or not you can use kRestoreMainWindows, a
  * define #KDE_RESTORE_MAIN_WINDOWS_NUM_TEMPLATE_ARGS is provided.
  *
- * These global convenience functions (that come with a varying
- * number of template arguments) are a replacement for the #RESTORE
- * macro provided in earlier versions of KDE. The old #RESTORE macro
- * is still provided for backwards compatibility.
- *
  * @see KMainWindow::restore()
- * @see #RESTORE
  * @see KMainWindow::classNameOfToplevel()
  **/
 template <typename T>
